Crate kcr_kom_kaiso_github_io

Crate kcr_kom_kaiso_github_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kom.kaiso.github.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

kom.kaiso.github.io/v1alpha1

  • Microservice

Modules

v1alpha1